Profile for 'Jeffrey of YOSPOS' - The Something Awful Forums

Redacted

User Profile (Find posts by user) (Rap sheet)
Jeffrey of YOSPOS Dec 21, 2005 GET LOSE, YOU CAN'T COMPARE WITH MY POWERS | ### About Jeffrey of YOSPOS There have been 28605 posts made by Jeffrey of YOSPOS, an average of 4.13 posts per day, since registering on Dec 21, 2005. Jeffrey of YOSPOS claims to be a porpoise. Life is but a dreamA dream and a plan ### Staff information Jeffrey of YOSPOS is a forum administrator and moderates the following forum: Something Awful Celebration Kickoff: The Internet Made Us Stupid ### Contact Information Message Send a private message ICQ 42069 AIM not set Yahoo! not set Home Page not set ### User Picture ### Additional Info Member Since Dec 21, 2005 Post Count 28605 Post Rate 4.13 per day Last Post Dec 5, 2024 21:37

Powered by: vBulletin Version 2.2.9 (SABB-v2.24.12)
Copyright ©2000, 2001, Jelsoft Enterprises Limited.
Copyright ©2024, Jeffrey of YOSPOS
Privacy Policy